## Installation Process: 

`LINUX`

#### Method 1:

* Copy the egg file link in `Download files` tab
```
python3 -m easy_install <Download Link of Egg file>
```


## Usage

#### For Method 1: 

```
from awsService import comprehend

detect_entities(bucketName='datachef-2.0', fileKey='comprehend/comprehend.txt', fileType='S3')

```
